# coding=utf-8
from ...Classes.Abstracten.TechnischDocument import TechnischDocument
from ...Classes.ImplementatieElement.AIMNaamObject import AIMNaamObject
from otlmow_model.OtlmowModel.GeometrieTypes.PuntGeometrie import PuntGeometrie


# Generated with OTLClassCreator. To modify: extend, do not edit
class Kruk(TechnischDocument, AIMNaamObject, PuntGeometrie):
    """Een roterend mechanisch onderdeel dat werkt op moment en vaak in combinatie met een (drijf)stang gebruikt wordt om een roterende beweging om te zetten in een lineaire beweging of omgekeerd."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Kruk'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    def __init__(self):
        super().__init__()

        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Stang', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Stangenmechanisme', direction='o')  # o = direction: outgoing



# coding=utf-8
from typing import List
from otlmow_model.OtlmowModel.BaseClasses.OTLObject import OTLAttribuut
from abc import abstractmethod
from ...Classes.ImplementatieElement.AIMObject import AIMObject
from ...Datatypes.DtcDocument import DtcDocument, DtcDocumentWaarden


# Generated with OTLClassCreator. To modify: extend, do not edit
class LinkendElement(AIMObject):
    """Abstracte bedoeld om alle eigenschappen en relaties van linkende elementen te groeperen. Linkende elementen zijn objecten die aansluiten op een buis."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#LinkendElement'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    @abstractmethod
    def __init__(self):
        super().__init__()

        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Rioleringsstelsel', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#SluitAanOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Brandvoorziening', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#SluitAanOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Buis', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#SluitAanOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Brandvoorziening', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#SluitAanOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Buis', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#SluitAanOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#LinkendElement', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#SluitAanOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#PompSchroefEnWaaier', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#SluitAanOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#PutRelatie', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#SluitAanOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#WaterloopRelatie', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#SluitAanOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Pompkamer', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#SluitAanOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Waterweg', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#SluitAanOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Aansluitmof', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#SluitAanOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Aansluitopening', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#SluitAanOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Afsluiter', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#SluitAanOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Afsluitkraan', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#SluitAanOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Afwateringsgeul', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#SluitAanOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Aswegerput', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#SluitAanOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Brandhaspel', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#SluitAanOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Brandleiding', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#SluitAanOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Dompelpomp', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#SluitAanOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Draineerbuis', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#SluitAanOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Drukverhogingsgroep', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#SluitAanOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Flens', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#SluitAanOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Gracht', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#SluitAanOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Huisaansluitput', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#SluitAanOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Hulpstuk', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#SluitAanOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Hydrant', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#SluitAanOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Infiltratievoorziening', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#SluitAanOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Kamer', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#SluitAanOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Mantelbuis', direction='o', deprecated='2.8.0')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#SluitAanOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#OntluchterBrandleiding', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#SluitAanOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Ontluchtingsventiel', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#SluitAanOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#OpenInfiltratievoorziening', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#SluitAanOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Overstort', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#SluitAanOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Persleiding', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#SluitAanOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Pomp', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#SluitAanOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Reservoir', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#SluitAanOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Rioleringsbuis', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#SluitAanOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Riooltoegang', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#SluitAanOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Schacht', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#SluitAanOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Spaarbekken', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#SluitAanOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Straatkolk', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#SluitAanOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#StuurklepBrandleiding', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#SluitAanOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Taludgoot', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#SluitAanOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Terugslagklep', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#SluitAanOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Voetbocht', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#SluitAanOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#VulpuntBrandweer', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#SluitAanOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Waaier', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#SluitAanOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Waterloop', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#SluitAanOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Wervel', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#SluitAanOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Wormschroef', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#SluitAanOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#PutRelatie', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#SluitAanOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#WaterloopRelatie', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#SluitAanOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Afwateringsgeul', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#SluitAanOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#OpenInfiltratievoorziening', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#SluitAanOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Spaarbekken', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#SluitAanOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Taludgoot', direction='i')  # i = direction: incoming

        self._technischeFiche = OTLAttribuut(field=DtcDocument,
                                             naam='technischeFiche',
                                             label='technische fiche',
                                             objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#LinkendElement.technischeFiche',
                                             kardinaliteit_max='*',
                                             definition='De technische fiche van een linkend element.',
                                             owner=self)

    @property
    def technischeFiche(self) -> List[DtcDocumentWaarden]:
        """De technische fiche van een linkend element."""
        return self._technischeFiche.get_waarde()

    @technischeFiche.setter
    def technischeFiche(self, value):
        self._technischeFiche.set_waarde(value, owner=self)



# coding=utf-8
from datetime import date
from otlmow_model.OtlmowModel.BaseClasses.OTLObject import OTLAttribuut
from ...Classes.Abstracten.SerienummerObject import SerienummerObject
from ...Classes.Abstracten.Voedingspunt import Voedingspunt
from otlmow_model.OtlmowModel.BaseClasses.DateField import DateField
from ...Datatypes.DtcAfmetingBxhInMm import DtcAfmetingBxhInMm, DtcAfmetingBxhInMmWaarden
from ...Datatypes.KlBatterijMateriaal import KlBatterijMateriaal
from ...Datatypes.KlBatterijMerk import KlBatterijMerk
from ...Datatypes.KlBatterijModelnaam import KlBatterijModelnaam
from ...Datatypes.KwantWrdInAmpereUur import KwantWrdInAmpereUur, KwantWrdInAmpereUurWaarden
from ...Datatypes.KwantWrdInVolt import KwantWrdInVolt, KwantWrdInVoltWaarden
from otlmow_model.OtlmowModel.GeometrieTypes.PuntGeometrie import PuntGeometrie


# Generated with OTLClassCreator. To modify: extend, do not edit
class Batterij(SerienummerObject, Voedingspunt, PuntGeometrie):
    """Element bestaande uit meerdere elektrochemische cellen voor het leveren van elektriciteit,die ontstaat door de omzetting van opgeslagen chemische energie in elektrische energie."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Batterij'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    def __init__(self):
        super().__init__()

        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Kast', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestigingsbeugel', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#FietstelDisplay', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#PMU', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Voedt', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#FietstelDisplay', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Voedt', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Fietstelsysteem', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Voedt', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Laagspanningsbord', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Voedt', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Ontvanger', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Voedt', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#PMU', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Voedt', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Spanningsomvormer', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Voedt', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Stroomkring', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Voedt', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Toegangscontroller', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Voedt', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#UPS', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Voedt', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#WeggebondenDetector', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Voedt', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Batterijlader', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Voedt', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Laagspanningsbord', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Voedt', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#PMU', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Voedt', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Stroomkring', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Voedt', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Zonnepaneel', direction='i')  # i = direction: incoming

        self._afmetingen = OTLAttribuut(field=DtcAfmetingBxhInMm,
                                        naam='afmetingen',
                                        label='afmetingen',
                                        objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Batterij.afmetingen',
                                        definition='De afmetingen van de batterij in millimeter.',
                                        owner=self)

        self._fabricatiedatum = OTLAttribuut(field=DateField,
                                             naam='fabricatiedatum',
                                             label='fabricatiedatum',
                                             objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Batterij.fabricatiedatum',
                                             definition='De datum waarop de batterij geproduceerd is.',
                                             owner=self)

        self._lading = OTLAttribuut(field=KwantWrdInAmpereUur,
                                    naam='lading',
                                    label='lading',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Batterij.lading',
                                    usagenote='Het gaat om de lading van de batterij vlak na productie wanneer de batterij volledig opgeladen is. De maximale lading dus.',
                                    definition='Wordt ook wel capaciteit of autonomie genoemd. Geeft aan hoe veel energie de batterij kan leveren in volledig opgeladen staat.',
                                    owner=self)

        self._materiaal = OTLAttribuut(field=KlBatterijMateriaal,
                                       naam='materiaal',
                                       label='materiaal',
                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Batterij.materiaal',
                                       definition='Het materiaal waaruit de batterij gemaakt is. Het gaat hier om het materiaal waarin de lading opgeslagen is.',
                                       owner=self)

        self._merk = OTLAttribuut(field=KlBatterijMerk,
                                  naam='merk',
                                  label='merk',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Batterij.merk',
                                  definition='Merk van de batterij.',
                                  owner=self)

        self._modelnaam = OTLAttribuut(field=KlBatterijModelnaam,
                                       naam='modelnaam',
                                       label='modelnaam',
                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Batterij.modelnaam',
                                       definition='Modelnaam van de batterij.',
                                       owner=self)

        self._spanning = OTLAttribuut(field=KwantWrdInVolt,
                                      naam='spanning',
                                      label='spanning',
                                      objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Batterij.spanning',
                                      definition='De spanning die de batterij kan leveren. Wordt ook wel het werkingsvoltage genoemd.',
                                      owner=self)

    @property
    def afmetingen(self) -> DtcAfmetingBxhInMmWaarden:
        """De afmetingen van de batterij in millimeter."""
        return self._afmetingen.get_waarde()

    @afmetingen.setter
    def afmetingen(self, value):
        self._afmetingen.set_waarde(value, owner=self)

    @property
    def fabricatiedatum(self) -> date:
        """De datum waarop de batterij geproduceerd is."""
        return self._fabricatiedatum.get_waarde()

    @fabricatiedatum.setter
    def fabricatiedatum(self, value):
        self._fabricatiedatum.set_waarde(value, owner=self)

    @property
    def lading(self) -> KwantWrdInAmpereUurWaarden:
        """Wordt ook wel capaciteit of autonomie genoemd. Geeft aan hoe veel energie de batterij kan leveren in volledig opgeladen staat."""
        return self._lading.get_waarde()

    @lading.setter
    def lading(self, value):
        self._lading.set_waarde(value, owner=self)

    @property
    def materiaal(self) -> str:
        """Het materiaal waaruit de batterij gemaakt is. Het gaat hier om het materiaal waarin de lading opgeslagen is."""
        return self._materiaal.get_waarde()

    @materiaal.setter
    def materiaal(self, value):
        self._materiaal.set_waarde(value, owner=self)

    @property
    def merk(self) -> str:
        """Merk van de batterij."""
        return self._merk.get_waarde()

    @merk.setter
    def merk(self, value):
        self._merk.set_waarde(value, owner=self)

    @property
    def modelnaam(self) -> str:
        """Modelnaam van de batterij."""
        return self._modelnaam.get_waarde()

    @modelnaam.setter
    def modelnaam(self, value):
        self._modelnaam.set_waarde(value, owner=self)

    @property
    def spanning(self) -> KwantWrdInVoltWaarden:
        """De spanning die de batterij kan leveren. Wordt ook wel het werkingsvoltage genoemd."""
        return self._spanning.get_waarde()

    @spanning.setter
    def spanning(self, value):
        self._spanning.set_waarde(value, owner=self)



# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.KeuzelijstField import KeuzelijstField
from otlmow_model.OtlmowModel.BaseClasses.KeuzelijstWaarde import KeuzelijstWaarde


# Generated with OTLEnumerationCreator. To modify: extend, do not edit
class KlMateriaalStenen(KeuzelijstField):
    """Het materiaal van de stenen."""
    naam = 'KlMateriaalStenen'
    label = 'Materiaal stenen'
    objectUri = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#KlMateriaalStenen'
    definition = 'Het materiaal van de stenen.'
    status = 'ingebruik'
    codelist = 'https://wegenenverkeer.data.vlaanderen.be/id/conceptscheme/KlMateriaalStenen'
    options = {
        'beton': KeuzelijstWaarde(invulwaarde='beton',
                                  label='Beton',
                                  status='ingebruik',
                                  definitie='Betonspecie van zand, cement, grind, water en eventueel vulstoffen en hulpstoffen.',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlMateriaalStenen/beton'),
        'blauwe-hardsteen-volgens-categorie-a': KeuzelijstWaarde(invulwaarde='blauwe-hardsteen-volgens-categorie-a',
                                                                 label='Blauwe hardsteen volgens categorie A',
                                                                 status='ingebruik',
                                                                 definitie='Ook wel: Petit Granit. Een natuursteen met een natuurlijke blauwgrijze kleur door de aanwezigheid van crinoÃ¯deresten samengeklit met microkristallijn calciet. Blauwe hardsteen van categorie A wordt gebruikt in beeldhouwwerken, grafzerken of werken met een uitzonderlijke afwerking.',
                                                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlMateriaalStenen/blauwe-hardsteen-volgens-categorie-a'),
        'blauwe-hardsteen-volgens-categorie-b': KeuzelijstWaarde(invulwaarde='blauwe-hardsteen-volgens-categorie-b',
                                                                 label='Blauwe hardsteen volgens categorie B',
                                                                 status='ingebruik',
                                                                 definitie='Ook wel: Petit Granit. Een natuursteen met een natuurlijke blauwgrijze kleur door de aanwezigheid van crinoÃ¯deresten samengeklit met microkristallijn calciet. Blauwe hardsteen van categorie B wordt gebruikt in bouwwerken, restauratiewerken of marmerwerken.',
                                                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlMateriaalStenen/blauwe-hardsteen-volgens-categorie-b'),
        'blauwe-hardsteen-volgens-categorie-c': KeuzelijstWaarde(invulwaarde='blauwe-hardsteen-volgens-categorie-c',
                                                                 label='Blauwe hardsteen volgens categorie C',
                                                                 status='ingebruik',
                                                                 definitie='Ook wel: Petit Granit. Een natuursteen met een natuurlijke blauwgrijze kleur door de aanwezigheid van crinoÃ¯deresten samengeklit met microkristallijn calciet. Blauwe hardsteen van categorie C wordt gebruikt in houwstenen of bekledingswerken.',
                                                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlMateriaalStenen/blauwe-hardsteen-volgens-categorie-c'),
        'breuksteen': KeuzelijstWaarde(invulwaarde='breuksteen',
                                       label='Breuksteen',
                                       status='ingebruik',
                                       definitie='Breuksteen is een natuursteen van onregelmatige vorm.',
                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlMateriaalStenen/breuksteen'),
        'cellenbeton': KeuzelijstWaarde(invulwaarde='cellenbeton',
                                        label='Cellenbeton',
                                        status='ingebruik',
                                        definitie='Ook wel: gasbeton. Dit is een betonsoort die gekenmerkt wordt door zijn lage dichtheid en sterk isolerend vermogen. Het bekendste merk is Ytong.',
                                        objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlMateriaalStenen/cellenbeton'),
        'crino-denkalksteen': KeuzelijstWaarde(invulwaarde='crino-denkalksteen',
                                               label='Crinoïdenkalksteen',
                                               status='ingebruik',
                                               definitie='Kalksteen met vele overblijfselen, voornamelijk stengeldelen, van Crinoiden of Haarsterren.',
                                               objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlMateriaalStenen/crino-denkalksteen'),
        'gevelsteen': KeuzelijstWaarde(invulwaarde='gevelsteen',
                                       label='Gevelsteen',
                                       status='ingebruik',
                                       definitie='Een gevelsteen is een baksteen die toegepast kan worden als buitengevelsteen.',
                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlMateriaalStenen/gevelsteen'),
        'kalksteen': KeuzelijstWaarde(invulwaarde='kalksteen',
                                      label='Kalksteen',
                                      status='ingebruik',
                                      definitie='Een natuursteen, ontstaan door kalkafzettingen.',
                                      objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlMateriaalStenen/kalksteen'),
        'leisteen': KeuzelijstWaarde(invulwaarde='leisteen',
                                     label='Leisteen',
                                     status='ingebruik',
                                     definitie='Een metamorf gesteente dat gekenmerkt is door een duidelijke foliatie van afwisselende laagjes kwarts en andere mineralen.',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlMateriaalStenen/leisteen'),
        'natuursteen': KeuzelijstWaarde(invulwaarde='natuursteen',
                                        label='Natuursteen',
                                        status='ingebruik',
                                        definitie='Een gesteente dat in de natuur wordt aangetroffen en dat, na een eventuele bewerking, geschikt is als bouwmateriaal.',
                                        objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlMateriaalStenen/natuursteen'),
        'snelbouwsteen': KeuzelijstWaarde(invulwaarde='snelbouwsteen',
                                          label='Snelbouwsteen',
                                          status='ingebruik',
                                          definitie='Dit is een keramische binnenmuursteen die vooral uit klei(houdende) materialen bestaat, al dan niet gemengd met zand en andere toeslagstoffen.',
                                          objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlMateriaalStenen/snelbouwsteen'),
        'volle-baksteen': KeuzelijstWaarde(invulwaarde='volle-baksteen',
                                           label='Volle baksteen',
                                           status='ingebruik',
                                           definitie='Aarde die in een bepaald vorm gebakken wordt.',
                                           objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlMateriaalStenen/volle-baksteen'),
        'zandsteen': KeuzelijstWaarde(invulwaarde='zandsteen',
                                      label='Zandsteen',
                                      status='ingebruik',
                                      definitie='Een afzettingsgesteente dat voornamelijk bestaat uit zand/kwartskorrels die met elkaar verbonden werden met een bindmiddel (leem, kalk,...).',
                                      objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlMateriaalStenen/zandsteen')
    }

    @classmethod
    def create_dummy_data(cls):
        return cls.create_dummy_data_keuzelijst(cls.options)




# coding=utf-8
from ...Classes.Abstracten.GrazigeVegetatie import GrazigeVegetatie


# Generated with OTLClassCreator. To modify: extend, do not edit
class Grasmat(GrazigeVegetatie):
    """Grasvegetatie die een uniforme zode vormt met veel grassen en zeer regelmatig wordt gemaaid."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Grasmat'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    def __init__(self):
        super().__init__()

        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HeeftBeheer', target='https://wegenenverkeer.data.vlaanderen.be/ns/levenscyclus#BeheerGrazigeVegetatie', direction='o')  # o = direction: outgoing



# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.OTLObject import OTLAttribuut
from ...Classes.Abstracten.ElektrischComponentennummerObject import ElektrischComponentennummerObject
from ...Classes.Abstracten.MotorVermogenskring import MotorVermogenskring
from ...Classes.Abstracten.SerienummerObject import SerienummerObject
from ...Classes.ImplementatieElement.AIMNaamObject import AIMNaamObject
from otlmow_model.OtlmowModel.BaseClasses.BooleanField import BooleanField
from ...Datatypes.DtcDocument import DtcDocument, DtcDocumentWaarden
from ...Datatypes.KlMotorbeveiligingMerk import KlMotorbeveiligingMerk
from ...Datatypes.KlMotorbeveiligingModelnaam import KlMotorbeveiligingModelnaam
from ...Datatypes.KlMotorbeveiligingType import KlMotorbeveiligingType


# Generated with OTLClassCreator. To modify: extend, do not edit
class Motorbeveiligingsschakelaar(ElektrischComponentennummerObject, MotorVermogenskring, SerienummerObject, AIMNaamObject):
    """Techniek voor het beveiliging van een moter tegen schade door overbelasting."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Motorbeveiligingsschakelaar'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    def __init__(self):
        super().__init__()

        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#VoedtAangestuurd', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#MotorVermogenskring', direction='i')  # i = direction: incoming

        self._instellingen = OTLAttribuut(field=DtcDocument,
                                          naam='instellingen',
                                          label='instellingen',
                                          objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Motorbeveiligingsschakelaar.instellingen',
                                          definition='Een bestandsbijlage met de gedetailleerde beschrjiving van de instellingen van het toestel.',
                                          owner=self)

        self._isInstelbaar = OTLAttribuut(field=BooleanField,
                                          naam='isInstelbaar',
                                          label='is instelbaar',
                                          objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Motorbeveiligingsschakelaar.isInstelbaar',
                                          definition='Geeft aan of het toestel instelbaar is na oplevering of niet.',
                                          owner=self)

        self._merk = OTLAttribuut(field=KlMotorbeveiligingMerk,
                                  naam='merk',
                                  label='merk',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Motorbeveiligingsschakelaar.merk',
                                  definition='Merk van de motorbeveiligingsschakelaar volgens de fabrikant.',
                                  owner=self)

        self._modelnaam = OTLAttribuut(field=KlMotorbeveiligingModelnaam,
                                       naam='modelnaam',
                                       label='modelnaam',
                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Motorbeveiligingsschakelaar.modelnaam',
                                       definition='Naam die de fabrikant zelf geeft aan het model of de uitvoering van de motorbeveiligingsschakelaar.',
                                       owner=self)

        self._type = OTLAttribuut(field=KlMotorbeveiligingType,
                                  naam='type',
                                  label='type',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Motorbeveiligingsschakelaar.type',
                                  definition='Het type van motorbeveiliging volgens de gebruikte techniek.',
                                  owner=self)

    @property
    def instellingen(self) -> DtcDocumentWaarden:
        """Een bestandsbijlage met de gedetailleerde beschrjiving van de instellingen van het toestel."""
        return self._instellingen.get_waarde()

    @instellingen.setter
    def instellingen(self, value):
        self._instellingen.set_waarde(value, owner=self)

    @property
    def isInstelbaar(self) -> bool:
        """Geeft aan of het toestel instelbaar is na oplevering of niet."""
        return self._isInstelbaar.get_waarde()

    @isInstelbaar.setter
    def isInstelbaar(self, value):
        self._isInstelbaar.set_waarde(value, owner=self)

    @property
    def merk(self) -> str:
        """Merk van de motorbeveiligingsschakelaar volgens de fabrikant."""
        return self._merk.get_waarde()

    @merk.setter
    def merk(self, value):
        self._merk.set_waarde(value, owner=self)

    @property
    def modelnaam(self) -> str:
        """Naam die de fabrikant zelf geeft aan het model of de uitvoering van de motorbeveiligingsschakelaar."""
        return self._modelnaam.get_waarde()

    @modelnaam.setter
    def modelnaam(self, value):
        self._modelnaam.set_waarde(value, owner=self)

    @property
    def type(self) -> str:
        """Het type van motorbeveiliging volgens de gebruikte techniek."""
        return self._type.get_waarde()

    @type.setter
    def type(self, value):
        self._type.set_waarde(value, owner=self)



# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.KeuzelijstField import KeuzelijstField
from otlmow_model.OtlmowModel.BaseClasses.KeuzelijstWaarde import KeuzelijstWaarde


# Generated with OTLEnumerationCreator. To modify: extend, do not edit
class KlKleurSupp(KeuzelijstField):
    """Keuzelijst om de kleur van de toegevoegde supplementen van de verharding te bepalen."""
    naam = 'KlKleurSupp'
    label = 'Kleur supplementen'
    objectUri = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#KlKleurSupp'
    definition = 'Keuzelijst om de kleur van de toegevoegde supplementen van de verharding te bepalen.'
    status = 'ingebruik'
    codelist = 'https://wegenenverkeer.data.vlaanderen.be/id/conceptscheme/KlKleurSupp'
    options = {
        'beige': KeuzelijstWaarde(invulwaarde='beige',
                                  label='beige',
                                  status='ingebruik',
                                  definitie='De kleur beige.',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlKleurSupp/beige'),
        'bordeaux-bruin': KeuzelijstWaarde(invulwaarde='bordeaux-bruin',
                                           label='bordeaux-bruin',
                                           status='ingebruik',
                                           definitie='De kleur bordeaux/bruin.',
                                           objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlKleurSupp/bordeaux-bruin'),
        'geen': KeuzelijstWaarde(invulwaarde='geen',
                                 label='geen',
                                 status='ingebruik',
                                 definitie='Geen of standaard kleur.',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlKleurSupp/geen'),
        'oker': KeuzelijstWaarde(invulwaarde='oker',
                                 label='oker',
                                 status='ingebruik',
                                 definitie='De kleur oker.',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlKleurSupp/oker'),
        'rood': KeuzelijstWaarde(invulwaarde='rood',
                                 label='rood',
                                 status='ingebruik',
                                 definitie='De kleur rood.',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlKleurSupp/rood')
    }

    @classmethod
    def create_dummy_data(cls):
        return cls.create_dummy_data_keuzelijst(cls.options)




# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.KeuzelijstField import KeuzelijstField
from otlmow_model.OtlmowModel.BaseClasses.KeuzelijstWaarde import KeuzelijstWaarde


# Generated with OTLEnumerationCreator. To modify: extend, do not edit
class KlStortsteenType(KeuzelijstField):
    """Stortsteen types."""
    naam = 'KlStortsteenType'
    label = 'Stortsteen type'
    objectUri = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#KlStortsteenType'
    definition = 'Stortsteen types.'
    status = 'ingebruik'
    codelist = 'https://wegenenverkeer.data.vlaanderen.be/id/conceptscheme/KlStortsteenType'
    options = {
        'brokken-van-betonpuin': KeuzelijstWaarde(invulwaarde='brokken-van-betonpuin',
                                                  label='brokken van betonpuin',
                                                  status='ingebruik',
                                                  definitie='brokken van betonpuin',
                                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlStortsteenType/brokken-van-betonpuin'),
        'brokken-van-breuksteenpuin': KeuzelijstWaarde(invulwaarde='brokken-van-breuksteenpuin',
                                                       label='brokken van breuksteenpuin',
                                                       status='ingebruik',
                                                       definitie='brokken van breuksteenpuin',
                                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlStortsteenType/brokken-van-breuksteenpuin'),
        'brokken-van-mengpuin': KeuzelijstWaarde(invulwaarde='brokken-van-mengpuin',
                                                 label='brokken van mengpuin',
                                                 status='ingebruik',
                                                 definitie='brokken van mengpuin',
                                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlStortsteenType/brokken-van-mengpuin'),
        'brokken-van-metselwerkpuin': KeuzelijstWaarde(invulwaarde='brokken-van-metselwerkpuin',
                                                       label='brokken van metselwerkpuin',
                                                       status='ingebruik',
                                                       definitie='brokken van metselwerkpuin',
                                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlStortsteenType/brokken-van-metselwerkpuin'),
        'dolomiet': KeuzelijstWaarde(invulwaarde='dolomiet',
                                     label='dolomiet',
                                     status='ingebruik',
                                     definitie='dolomiet',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlStortsteenType/dolomiet'),
        'kunststeenslag': KeuzelijstWaarde(invulwaarde='kunststeenslag',
                                           label='kunststeenslag',
                                           status='ingebruik',
                                           definitie='brokken van betonpuin',
                                           objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlStortsteenType/kunststeenslag'),
        'natuursteenslag': KeuzelijstWaarde(invulwaarde='natuursteenslag',
                                            label='natuursteenslag',
                                            status='ingebruik',
                                            definitie='natuursteenslag',
                                            objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlStortsteenType/natuursteenslag'),
        'rolgrind': KeuzelijstWaarde(invulwaarde='rolgrind',
                                     label='rolgrind',
                                     status='ingebruik',
                                     definitie='Grind met goed afgeronde korrels.',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlStortsteenType/rolgrind'),
        'rolsteen': KeuzelijstWaarde(invulwaarde='rolsteen',
                                     label='rolsteen',
                                     status='ingebruik',
                                     definitie='rolsteen',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlStortsteenType/rolsteen'),
        'ruwe-breuksteen': KeuzelijstWaarde(invulwaarde='ruwe-breuksteen',
                                            label='ruwe breuksteen',
                                            status='ingebruik',
                                            definitie='een natuursteen van onregelmatige vorm',
                                            objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlStortsteenType/ruwe-breuksteen')
    }

    @classmethod
    def create_dummy_data(cls):
        return cls.create_dummy_data_keuzelijst(cls.options)




# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.KeuzelijstField import KeuzelijstField


# Generated with OTLEnumerationCreator. To modify: extend, do not edit
class KlVetType(KeuzelijstField):
    """De verschillende soorten vet die kunnen worden gebruikt voor smering."""
    naam = 'KlVetType'
    label = 'Vet type'
    objectUri = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#KlVetType'
    definition = 'De verschillende soorten vet die kunnen worden gebruikt voor smering.'
    status = 'ingebruik'
    codelist = 'https://wegenenverkeer.data.vlaanderen.be/id/conceptscheme/KlVetType'
    options = {
    }

    @classmethod
    def create_dummy_data(cls):
        return cls.create_dummy_data_keuzelijst(cls.options)




# coding=utf-8
from ...Classes.ImplementatieElement.AIMNaamObject import AIMNaamObject
from otlmow_model.OtlmowModel.GeometrieTypes.VlakGeometrie import VlakGeometrie


# Generated with OTLClassCreator. To modify: extend, do not edit
class Grondverbetering(AIMNaamObject, VlakGeometrie):
    """Proces waarbij de fysieke eigenschappen van de grond worden aangepast om de draagkracht te verhogen, de samendrukbaarheid te verminderen, en de stabiliteit te verbeteren, door technieken zoals verdichting, chemische stabilisatie, het gebruik van geokunststoffen, en het aanbrengen van grindkernen."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Grondverbetering'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    def __init__(self):
        super().__init__()

        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Grindkern', direction='i')  # i = direction: incoming



from abc import abstractmethod
from pathlib import Path

from otlmow_model.OtlmowModel.Helpers.generated_lists import get_hardcoded_class_dict, get_concrete_subclasses_from_class_dict


class RelationInteractor:
    typeURI = ''
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    def add_valid_relation(self, relation: str, target: str, direction: str = 'o', deprecated: str = ''):
        if relation not in self._valid_relations:
            self._valid_relations[relation] = {}
        if target not in self._valid_relations[relation]:
            self._valid_relations[relation][target] = {}
        self._valid_relations[relation][target][direction] = deprecated

    @abstractmethod
    def __init__(self):
        super().__init__()

        self._valid_relations = {}

    def _get_all_concrete_relations(self, model_directory: Path = None):
        class_dict = get_hardcoded_class_dict(model_directory)
        for relation in self._valid_relations:
            for target in self._valid_relations[relation]:
                for direction, deprecated in self._valid_relations[relation][target].items():
                    if class_dict[target]['abstract']:
                        for subclass in get_concrete_subclasses_from_class_dict(target, model_directory=model_directory):
                            if direction == 'o':
                                yield self.typeURI, relation, subclass, '', deprecated
                            elif direction == 'i':
                                yield subclass, relation, self.typeURI, '', deprecated
                            elif direction == 'u':
                                yield self.typeURI, relation, subclass, 'Unspecified', deprecated
                    else:
                        if direction == 'o':
                            yield self.typeURI, relation, target, '', deprecated
                        elif direction == 'i':
                            yield target, relation, self.typeURI, '', deprecated
                        elif direction == 'u':
                            yield self.typeURI, relation, target, 'Unspecified', deprecated



# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.KeuzelijstField import KeuzelijstField
from otlmow_model.OtlmowModel.BaseClasses.KeuzelijstWaarde import KeuzelijstWaarde


# Generated with OTLEnumerationCreator. To modify: extend, do not edit
class KlDynBordRVMSModelnaam(KeuzelijstField):
    """Keuzelijst met de gangbare modelnamen van RVMS borden. De modelnamen worden meestal door de leverancier of fabrikant bepaald."""
    naam = 'KlDynBordRVMSModelnaam'
    label = 'Dyn bord RVMS modelnaam'
    objectUri = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#KlDynBordRVMSModelnaam'
    definition = 'Keuzelijst met de gangbare modelnamen van RVMS borden. De modelnamen worden meestal door de leverancier of fabrikant bepaald.'
    status = 'ingebruik'
    codelist = 'https://wegenenverkeer.data.vlaanderen.be/id/conceptscheme/KlDynBordRVMSModelnaam'
    options = {
        'RVMS-06I04': KeuzelijstWaarde(invulwaarde='RVMS-06I04',
                                       label='RVMS-06I04',
                                       status='ingebruik',
                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlDynBordRVMSModelnaam/RVMS-06I04'),
        'RVMS-12F05': KeuzelijstWaarde(invulwaarde='RVMS-12F05',
                                       label='RVMS-12F05',
                                       status='ingebruik',
                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlDynBordRVMSModelnaam/RVMS-12F05'),
        'vms-g1-rgb-112-144s': KeuzelijstWaarde(invulwaarde='vms-g1-rgb-112-144s',
                                                label='VMS.G1.RGB.112.144S',
                                                status='ingebruik',
                                                definitie='VMS.G1.RGB.112.144S',
                                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlDynBordRVMSModelnaam/vms-g1-rgb-112-144s'),
        'vms-g1-rgb-96-64s': KeuzelijstWaarde(invulwaarde='vms-g1-rgb-96-64s',
                                              label='VMS.G1.RGB.96.64S',
                                              status='ingebruik',
                                              definitie='VMS.G1.RGB.96.64S',
                                              objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlDynBordRVMSModelnaam/vms-g1-rgb-96-64s'),
        'vms1-f-4140x3230-3g-rb-ecofc2': KeuzelijstWaarde(invulwaarde='vms1-f-4140x3230-3g-rb-ecofc2',
                                                          label='VMS1.F.4140x3230.3G.RB.ECOFC2',
                                                          status='ingebruik',
                                                          definitie='VMS1-F-4140x3230-3G-RB-ECOFC2',
                                                          objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlDynBordRVMSModelnaam/vms1-f-4140x3230-3g-rb-ecofc2')
    }

    @classmethod
    def create_dummy_data(cls):
        return cls.create_dummy_data_keuzelijst(cls.options)




# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.KeuzelijstField import KeuzelijstField
from otlmow_model.OtlmowModel.BaseClasses.KeuzelijstWaarde import KeuzelijstWaarde


# Generated with OTLEnumerationCreator. To modify: extend, do not edit
class KlTypeBrugligger(KeuzelijstField):
    """Het type van de brugligger."""
    naam = 'KlTypeBrugligger'
    label = 'Type brugligger'
    objectUri = 'https://wegenenverkeer.data.vlaanderen.be/ns/installatie#KlTypeBrugligger'
    definition = 'Het type van de brugligger.'
    status = 'ingebruik'
    codelist = 'https://wegenenverkeer.data.vlaanderen.be/id/conceptscheme/KlTypeBrugligger'
    options = {
        'dwarsdrager': KeuzelijstWaarde(invulwaarde='dwarsdrager',
                                        label='Dwarsdrager',
                                        status='ingebruik',
                                        definitie='Balk of ligger volgens de dwarsrichting van de brug die één of meerdere van volgende functies vervult:biedt ondersteuning aan het brugdek en/of de langsliggers en/of de hoofdliggers,verstijft de langs- en/of hoofdliggers,draagt de belastingen af naar de hoofdliggers,bevordert de samenwerking tussen de hoofdliggers.',
                                        objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlTypeBrugligger/dwarsdrager'),
        'hoofdligger': KeuzelijstWaarde(invulwaarde='hoofdligger',
                                        label='Hoofdligger',
                                        status='ingebruik',
                                        definitie='Primaire dragende balk of ligger volgens de lengterichting van de brug, die de belastingen afdraagt naar de oplegpunten van de brug, hetzij rechtstreeks, hetzij via einddwarsdragers/diafragma’s.',
                                        objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlTypeBrugligger/hoofdligger'),
        'langsligger': KeuzelijstWaarde(invulwaarde='langsligger',
                                        label='Langsligger',
                                        status='ingebruik',
                                        definitie='Secundaire balk of ligger volgens de lengterichting van de brug, die ondersteuning biedt aan het brugdek en de belastingen erop afdraagt naar de dwarsliggers.',
                                        objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlTypeBrugligger/langsligger')
    }

    @classmethod
    def create_dummy_data(cls):
        return cls.create_dummy_data_keuzelijst(cls.options)




# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.KeuzelijstField import KeuzelijstField
from otlmow_model.OtlmowModel.BaseClasses.KeuzelijstWaarde import KeuzelijstWaarde


# Generated with OTLEnumerationCreator. To modify: extend, do not edit
class KlBewegingssensorDetectiemethode(KeuzelijstField):
    """De methode waarvolgens de detectie gebeurt."""
    naam = 'KlBewegingssensorDetectiemethode'
    label = 'Bewegingssensor detectiemethode'
    objectUri = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#KlBewegingssensorDetectiemethode'
    definition = 'De methode waarvolgens de detectie gebeurt.'
    status = 'ingebruik'
    codelist = 'https://wegenenverkeer.data.vlaanderen.be/id/conceptscheme/KlBewegingssensorDetectiemethode'
    options = {
        'actief-infrarood-(air)': KeuzelijstWaarde(invulwaarde='actief-infrarood-(air)',
                                                   label='actief infrarood (AIR)',
                                                   status='ingebruik',
                                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlBewegingssensorDetectiemethode/actief-infrarood-(air)'),
        'microgolven-(hf)': KeuzelijstWaarde(invulwaarde='microgolven-(hf)',
                                             label='microgolven (HF)',
                                             status='ingebruik',
                                             objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlBewegingssensorDetectiemethode/microgolven-(hf)'),
        'passief-infrarood-(pir)': KeuzelijstWaarde(invulwaarde='passief-infrarood-(pir)',
                                                    label='passief infrarood (PIR)',
                                                    status='ingebruik',
                                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlBewegingssensorDetectiemethode/passief-infrarood-(pir)')
    }

    @classmethod
    def create_dummy_data(cls):
        return cls.create_dummy_data_keuzelijst(cls.options)




# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.OTLObject import OTLAttribuut
from ...Classes.Abstracten.TechnischDocument import TechnischDocument
from ...Classes.ImplementatieElement.AIMNaamObject import AIMNaamObject
from otlmow_model.OtlmowModel.BaseClasses.BooleanField import BooleanField
from ...Datatypes.KwantWrdInKiloNewton import KwantWrdInKiloNewton, KwantWrdInKiloNewtonWaarden
from ...Datatypes.KwantWrdInKilogram import KwantWrdInKilogram, KwantWrdInKilogramWaarden
from otlmow_model.OtlmowModel.GeometrieTypes.PuntGeometrie import PuntGeometrie


# Generated with OTLClassCreator. To modify: extend, do not edit
class Pendel(TechnischDocument, AIMNaamObject, PuntGeometrie):
    """Dit is een verticaal element, dubbelzijdig scharnierend, waarmee de roldeur ophangt aan de bovenrolwagen."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Pendel'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    def __init__(self):
        super().__init__()

        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Lager', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Rolwagenchassis', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Bovenrolwagen', direction='o')  # o = direction: outgoing

        self._gewicht = OTLAttribuut(field=KwantWrdInKilogram,
                                     naam='gewicht',
                                     label='gewicht',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Pendel.gewicht',
                                     definition='Het gewicht van de pendel, uitgedrukt in kilogram.',
                                     owner=self)

        self._heeftMeetcel = OTLAttribuut(field=BooleanField,
                                          naam='heeftMeetcel',
                                          label='heeft meetcel',
                                          objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Pendel.heeftMeetcel',
                                          definition='Geeft aan of de pendel een meetcel heeft of niet.',
                                          owner=self)

        self._karakteristiekeToelaatbareKracht = OTLAttribuut(field=KwantWrdInKiloNewton,
                                                              naam='karakteristiekeToelaatbareKracht',
                                                              label='karakteristieke toelaatbare kracht',
                                                              objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Pendel.karakteristiekeToelaatbareKracht',
                                                              definition='De maximale toelaatbare kracht.',
                                                              owner=self)

    @property
    def gewicht(self) -> KwantWrdInKilogramWaarden:
        """Het gewicht van de pendel, uitgedrukt in kilogram."""
        return self._gewicht.get_waarde()

    @gewicht.setter
    def gewicht(self, value):
        self._gewicht.set_waarde(value, owner=self)

    @property
    def heeftMeetcel(self) -> bool:
        """Geeft aan of de pendel een meetcel heeft of niet."""
        return self._heeftMeetcel.get_waarde()

    @heeftMeetcel.setter
    def heeftMeetcel(self, value):
        self._heeftMeetcel.set_waarde(value, owner=self)

    @property
    def karakteristiekeToelaatbareKracht(self) -> KwantWrdInKiloNewtonWaarden:
        """De maximale toelaatbare kracht."""
        return self._karakteristiekeToelaatbareKracht.get_waarde()

    @karakteristiekeToelaatbareKracht.setter
    def karakteristiekeToelaatbareKracht(self, value):
        self._karakteristiekeToelaatbareKracht.set_waarde(value, owner=self)



# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.KeuzelijstField import KeuzelijstField
from otlmow_model.OtlmowModel.BaseClasses.KeuzelijstWaarde import KeuzelijstWaarde


# Generated with OTLEnumerationCreator. To modify: extend, do not edit
class KlBestrijkingKaliber(KeuzelijstField):
    """De mogelijke kalibers."""
    naam = 'KlBestrijkingKaliber'
    label = 'kalibers'
    objectUri = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#KlBestrijkingKaliber'
    definition = 'De mogelijke kalibers.'
    status = 'ingebruik'
    codelist = 'https://wegenenverkeer.data.vlaanderen.be/id/conceptscheme/KlBestrijkingKaliber'
    options = {
        '2-10': KeuzelijstWaarde(invulwaarde='2-10',
                                 label='2/10',
                                 status='ingebruik',
                                 definitie='kaliber 2/10',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlBestrijkingKaliber/2-10'),
        '2-4': KeuzelijstWaarde(invulwaarde='2-4',
                                label='2/4',
                                status='ingebruik',
                                definitie='kaliber 2/4',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlBestrijkingKaliber/2-4'),
        '2-6.3': KeuzelijstWaarde(invulwaarde='2-6.3',
                                  label='2/6.3',
                                  status='ingebruik',
                                  definitie='kaliber 2/6.3',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlBestrijkingKaliber/2-6.3'),
        '4-10': KeuzelijstWaarde(invulwaarde='4-10',
                                 label='4/10',
                                 status='ingebruik',
                                 definitie='kaliber 4/10',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlBestrijkingKaliber/4-10'),
        '4-6.3': KeuzelijstWaarde(invulwaarde='4-6.3',
                                  label='4/6.3',
                                  status='ingebruik',
                                  definitie='kaliber 4/6.3',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlBestrijkingKaliber/4-6.3'),
        '6.3-10': KeuzelijstWaarde(invulwaarde='6.3-10',
                                   label='6.3/10',
                                   status='ingebruik',
                                   definitie='kaliber 6.3/10',
                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlBestrijkingKaliber/6.3-10')
    }

    @classmethod
    def create_dummy_data(cls):
        return cls.create_dummy_data_keuzelijst(cls.options)




# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.KeuzelijstField import KeuzelijstField
from otlmow_model.OtlmowModel.BaseClasses.KeuzelijstWaarde import KeuzelijstWaarde


# Generated with OTLEnumerationCreator. To modify: extend, do not edit
class KlSignaalControleModuleType(KeuzelijstField):
    """Het type van detectie dat uitgevoerd wordt door de signaal controle module."""
    naam = 'KlSignaalControleModuleType'
    label = 'Signaal controle module type'
    objectUri = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#KlSignaalControleModuleType'
    definition = 'Het type van detectie dat uitgevoerd wordt door de signaal controle module.'
    status = 'ingebruik'
    codelist = 'https://wegenenverkeer.data.vlaanderen.be/id/conceptscheme/KlSignaalControleModuleType'
    options = {
        'kabelbreuk': KeuzelijstWaarde(invulwaarde='kabelbreuk',
                                       label='kabelbreuk',
                                       status='ingebruik',
                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSignaalControleModuleType/kabelbreuk')
    }

    @classmethod
    def create_dummy_data(cls):
        return cls.create_dummy_data_keuzelijst(cls.options)




# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.KeuzelijstField import KeuzelijstField
from otlmow_model.OtlmowModel.BaseClasses.KeuzelijstWaarde import KeuzelijstWaarde


# Generated with OTLEnumerationCreator. To modify: extend, do not edit
class KlWindmeterType(KeuzelijstField):
    """Types van windmeters."""
    naam = 'KlWindmeterType'
    label = 'Windmeter type'
    objectUri = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#KlWindmeterType'
    definition = 'Types van windmeters.'
    status = 'ingebruik'
    codelist = 'https://wegenenverkeer.data.vlaanderen.be/id/conceptscheme/KlWindmeterType'
    options = {
        'ultrasoon': KeuzelijstWaarde(invulwaarde='ultrasoon',
                                      label='Ultrasoon',
                                      status='ingebruik',
                                      definitie='Ultrasoon',
                                      objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlWindmeterType/ultrasoon')
    }

    @classmethod
    def create_dummy_data(cls):
        return cls.create_dummy_data_keuzelijst(cls.options)




# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.OTLObject import OTLAttribuut
from ...Classes.ImplementatieElement.AIMNaamObject import AIMNaamObject
from otlmow_model.OtlmowModel.BaseClasses.BooleanField import BooleanField
from ...Datatypes.KlMateriaalVoegband import KlMateriaalVoegband
from otlmow_model.OtlmowModel.GeometrieTypes.PuntGeometrie import PuntGeometrie


# Generated with OTLClassCreator. To modify: extend, do not edit
class Voegband(AIMNaamObject, PuntGeometrie):
    """Een flexibel afdichtingselement dat wordt geplaatst in voegen van betonconstructies. Het doel van de voegband is om grond- en waterdichtheid te bieden en om een zekere (thermische) vervorming van de constructie op te vangen."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Voegband'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    def __init__(self):
        super().__init__()

        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Kesp', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Lmuur', direction='u')  # u = unidirectional

        self._isGeinjecteerd = OTLAttribuut(field=BooleanField,
                                            naam='isGeinjecteerd',
                                            label='is geïnjecteerd',
                                            objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Voegband.isGeinjecteerd',
                                            definition='Geeft aan of de voegband al dan niet geïnjecteerd is.',
                                            owner=self)

        self._materiaalVoegband = OTLAttribuut(field=KlMateriaalVoegband,
                                               naam='materiaalVoegband',
                                               label='materiaal voegband',
                                               objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Voegband.materiaalVoegband',
                                               definition='De verschillende opties van materiaal voor voegbanden.',
                                               owner=self)

    @property
    def isGeinjecteerd(self) -> bool:
        """Geeft aan of de voegband al dan niet geïnjecteerd is."""
        return self._isGeinjecteerd.get_waarde()

    @isGeinjecteerd.setter
    def isGeinjecteerd(self, value):
        self._isGeinjecteerd.set_waarde(value, owner=self)

    @property
    def materiaalVoegband(self) -> str:
        """De verschillende opties van materiaal voor voegbanden."""
        return self._materiaalVoegband.get_waarde()

    @materiaalVoegband.setter
    def materiaalVoegband(self, value):
        self._materiaalVoegband.set_waarde(value, owner=self)



# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.OTLObject import OTLAttribuut
from ...Classes.Abstracten.AanhorigheidKoker import AanhorigheidKoker
from ...Classes.Abstracten.AanhorigheidSluisStuw import AanhorigheidSluisStuw
from ...Classes.ImplementatieElement.AIMNaamObject import AIMNaamObject
from otlmow_model.OtlmowModel.BaseClasses.BooleanField import BooleanField
from ...Datatypes.KlMateriaalLoopvloer import KlMateriaalLoopvloer
from ...Datatypes.KwantWrdInKiloNewton import KwantWrdInKiloNewton, KwantWrdInKiloNewtonWaarden
from ...Datatypes.KwantWrdInKiloNewtonPerVierkanteMeter import KwantWrdInKiloNewtonPerVierkanteMeter, KwantWrdInKiloNewtonPerVierkanteMeterWaarden
from ...Datatypes.KwantWrdInMeter import KwantWrdInMeter, KwantWrdInMeterWaarden
from otlmow_model.OtlmowModel.GeometrieTypes.VlakGeometrie import VlakGeometrie


# Generated with OTLClassCreator. To modify: extend, do not edit
class Loopvloer(AanhorigheidKoker, AanhorigheidSluisStuw, AIMNaamObject, VlakGeometrie):
    """Een vloer die ligt op,in of nabij een constructie die wordt gebruikt om deze op een veilige manier te betreden of bereiken."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Loopvloer'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    def __init__(self):
        super().__init__()

        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Kokerruimte', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Leuning', direction='u')  # u = unidirectional

        self._isDemonteerbaar = OTLAttribuut(field=BooleanField,
                                             naam='isDemonteerbaar',
                                             label='is demonteerbaar',
                                             objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Loopvloer.isDemonteerbaar',
                                             definition='Geeft aan of de loopvloer al dan niet demonteerbaar is.',
                                             owner=self)

        self._karakteristiekeGebruiksbelasting = OTLAttribuut(field=KwantWrdInKiloNewtonPerVierkanteMeter,
                                                              naam='karakteristiekeGebruiksbelasting',
                                                              label='karakteristieke gebruiksbelasting',
                                                              objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Loopvloer.karakteristiekeGebruiksbelasting',
                                                              definition='De karakteristieke gebruiksbelasting.',
                                                              owner=self)

        self._karakteristiekePuntbelasting = OTLAttribuut(field=KwantWrdInKiloNewton,
                                                          naam='karakteristiekePuntbelasting',
                                                          label='karakteristieke puntbelasting',
                                                          objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Loopvloer.karakteristiekePuntbelasting',
                                                          definition='De karakteristieke puntbelasting.',
                                                          owner=self)

        self._materiaal = OTLAttribuut(field=KlMateriaalLoopvloer,
                                       naam='materiaal',
                                       label='materiaal',
                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Loopvloer.materiaal',
                                       definition='De mogelijke materialen van een loopvloer.',
                                       owner=self)

        self._nuttigeBreedte = OTLAttribuut(field=KwantWrdInMeter,
                                            naam='nuttigeBreedte',
                                            label='nuttige breedte',
                                            objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Loopvloer.nuttigeBreedte',
                                            definition='De nuttige breedte van de loopvloer zoals bepaald door de smalste breedte.',
                                            owner=self)

    @property
    def isDemonteerbaar(self) -> bool:
        """Geeft aan of de loopvloer al dan niet demonteerbaar is."""
        return self._isDemonteerbaar.get_waarde()

    @isDemonteerbaar.setter
    def isDemonteerbaar(self, value):
        self._isDemonteerbaar.set_waarde(value, owner=self)

    @property
    def karakteristiekeGebruiksbelasting(self) -> KwantWrdInKiloNewtonPerVierkanteMeterWaarden:
        """De karakteristieke gebruiksbelasting."""
        return self._karakteristiekeGebruiksbelasting.get_waarde()

    @karakteristiekeGebruiksbelasting.setter
    def karakteristiekeGebruiksbelasting(self, value):
        self._karakteristiekeGebruiksbelasting.set_waarde(value, owner=self)

    @property
    def karakteristiekePuntbelasting(self) -> KwantWrdInKiloNewtonWaarden:
        """De karakteristieke puntbelasting."""
        return self._karakteristiekePuntbelasting.get_waarde()

    @karakteristiekePuntbelasting.setter
    def karakteristiekePuntbelasting(self, value):
        self._karakteristiekePuntbelasting.set_waarde(value, owner=self)

    @property
    def materiaal(self) -> str:
        """De mogelijke materialen van een loopvloer."""
        return self._materiaal.get_waarde()

    @materiaal.setter
    def materiaal(self, value):
        self._materiaal.set_waarde(value, owner=self)

    @property
    def nuttigeBreedte(self) -> KwantWrdInMeterWaarden:
        """De nuttige breedte van de loopvloer zoals bepaald door de smalste breedte."""
        return self._nuttigeBreedte.get_waarde()

    @nuttigeBreedte.setter
    def nuttigeBreedte(self, value):
        self._nuttigeBreedte.set_waarde(value, owner=self)



# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.KeuzelijstField import KeuzelijstField
from otlmow_model.OtlmowModel.BaseClasses.KeuzelijstWaarde import KeuzelijstWaarde


# Generated with OTLEnumerationCreator. To modify: extend, do not edit
class KlBevestigingssteunType(KeuzelijstField):
    """De mogelijk types van een bevestigingssteun."""
    naam = 'KlBevestigingssteunType'
    label = 'Bevestigingssteun type'
    objectUri = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#KlBevestigingssteunType'
    definition = 'De mogelijk types van een bevestigingssteun.'
    status = 'ingebruik'
    codelist = 'https://wegenenverkeer.data.vlaanderen.be/id/conceptscheme/KlBevestigingssteunType'
    options = {
        'baar': KeuzelijstWaarde(invulwaarde='baar',
                                 label='baar',
                                 status='ingebruik',
                                 definitie='Een staaf waaraan bv. een antenne kan worden bevestigd.',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlBevestigingssteunType/baar')
    }

    @classmethod
    def create_dummy_data(cls):
        return cls.create_dummy_data_keuzelijst(cls.options)




# coding=utf-8
from ...Classes.Onderdeel.Grasland import Grasland


# Generated with OTLClassCreator. To modify: extend, do not edit
class GrassenmixGraslandfase1(Grasland):
    """G1 - Groen lappendeken met soorten uit G0 + kruipende boterbloem, paardenbloem,gewone hoornbloem (in enkelemonospecifieke haarden)."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#GrassenmixGraslandfase1'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    def __init__(self):
        super().__init__()



# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.ComplexField import ComplexField
from otlmow_model.OtlmowModel.BaseClasses.WaardenObject import WaardenObject
from otlmow_model.OtlmowModel.BaseClasses.OTLObject import OTLAttribuut
from otlmow_model.OtlmowModel.BaseClasses.StringField import StringField


class DteAssetTypeWaarden(WaardenObject):
    def __init__(self):
        WaardenObject.__init__(self)
        self._typeURI = OTLAttribuut(
            field=StringField,
            naam='typeURI',
            label='typeURI',
            objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/implementatieelement#AIMObject.typeURI',
            definition='De uri van het assettype.',
            owner=self)

    @property
    def typeURI(self):
        """De uri van het assettype."""
        return self._typeURI.get_waarde()

    @typeURI.setter
    def typeURI(self, value):
        self._typeURI.set_waarde(value, owner=self._parent)


class DteAssetType(ComplexField):
    """Complex datatype om het assettype te benoemen"""
    naam = 'DteAssetType'
    label = 'AssetType'
    objectUri = 'https://wegenenverkeer.data.vlaanderen.be/ns/implementatieelement#DteAssetType'
    definition = 'Complex datatype om het assettype te benoemen.'
    waardeObject = DteAssetTypeWaarden

    def __str__(self) -> str:
        return ComplexField.__str__(self)



# coding=utf-8
from ...Classes.Abstracten.StaalsoortObject import StaalsoortObject
from ...Classes.Abstracten.TechnischDocument import TechnischDocument
from ...Classes.ImplementatieElement.AIMNaamObject import AIMNaamObject
from otlmow_model.OtlmowModel.GeometrieTypes.PuntGeometrie import PuntGeometrie


# Generated with OTLClassCreator. To modify: extend, do not edit
class Wiel(StaalsoortObject, TechnischDocument, AIMNaamObject, PuntGeometrie):
    """Een rond een as draaiend element dat de verplaatsing van een object mogelijk maakt of de verplaatsing begeleidt waarbij de diameter groter is dan de breedte."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Wiel'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    def __init__(self):
        super().__init__()

        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Lager', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#AsMechanisch', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Bovenrolwagen', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Onderrolwagen', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Rolgeleiding', direction='o')  # o = direction: outgoing



# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.OTLObject import OTLAttribuut
from ...Classes.Abstracten.AfmetingenDiepCBWand import AfmetingenDiepCBWand
from ...Datatypes.DtcDocument import DtcDocument, DtcDocumentWaarden


# Generated with OTLClassCreator. To modify: extend, do not edit
class CementBentonietwand(AfmetingenDiepCBWand):
    """Wand waarbij een sleuf wordt gegraven en daarna wordt gevuld met een mengsel bestaande uit water, cement en bentoniet."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#CementBentonietwand'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    def __init__(self):
        super().__init__()

        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Behuizing', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#BekledingComponent', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Grondanker', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Hoppinzuil', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Inloopbehuizing', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#KabelgeleidingEnLeidingBevestiging', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Kast', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#NietWeggebondenDetectie', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Seinlantaarn', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#SteunStandaard', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Ventilatie', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Verkeersbord', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Verlichtingstoestel', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Waarschuwingslantaarn', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#ZenderOntvangerToegang', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Binnenverlichtingstoestel', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#LigtOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#ConstructieElement', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#LigtOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Laag', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#SluitAanOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#ComplexeGeleiding', direction='i')  # i = direction: incoming

        self._rekennota = OTLAttribuut(field=DtcDocument,
                                       naam='rekennota',
                                       label='rekennota',
                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#CementBentonietwand.rekennota',
                                       definition='Document met berekeningen.',
                                       owner=self)

        self._technischeFiche = OTLAttribuut(field=DtcDocument,
                                             naam='technischeFiche',
                                             label='technische fiche',
                                             objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#CementBentonietwand.technischeFiche',
                                             definition='Technisch document dat de technische details bevat.',
                                             owner=self)

    @property
    def rekennota(self) -> DtcDocumentWaarden:
        """Document met berekeningen."""
        return self._rekennota.get_waarde()

    @rekennota.setter
    def rekennota(self, value):
        self._rekennota.set_waarde(value, owner=self)

    @property
    def technischeFiche(self) -> DtcDocumentWaarden:
        """Technisch document dat de technische details bevat."""
        return self._technischeFiche.get_waarde()

    @technischeFiche.setter
    def technischeFiche(self, value):
        self._technischeFiche.set_waarde(value, owner=self)



# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.KeuzelijstField import KeuzelijstField
from otlmow_model.OtlmowModel.BaseClasses.KeuzelijstWaarde import KeuzelijstWaarde


# Generated with OTLEnumerationCreator. To modify: extend, do not edit
class KlEnergiemeterDNBMeteropnameFrequentie(KeuzelijstField):
    """Frequentie waarmee de meterstand opgenomen wordt door de netbeheerder."""
    naam = 'KlEnergiemeterDNBMeteropnameFrequentie'
    label = 'Energiemeter DNB meteropname frequentie'
    objectUri = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#KlEnergiemeterDNBMeteropnameFrequentie'
    definition = 'Frequentie waarmee de meterstand opgenomen wordt door de netbeheerder.'
    status = 'ingebruik'
    codelist = 'https://wegenenverkeer.data.vlaanderen.be/id/conceptscheme/KlEnergiemeterDNBMeteropnameFrequentie'
    options = {
        'AMR': KeuzelijstWaarde(invulwaarde='AMR',
                                label='AMR',
                                status='ingebruik',
                                definitie='automatische meter reading',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlEnergiemeterDNBMeteropnameFrequentie/AMR'),
        'MMR': KeuzelijstWaarde(invulwaarde='MMR',
                                label='MMR',
                                status='ingebruik',
                                definitie='manuele meter opname',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlEnergiemeterDNBMeteropnameFrequentie/MMR'),
        'YMR': KeuzelijstWaarde(invulwaarde='YMR',
                                label='YMR',
                                status='ingebruik',
                                definitie='jaarlijkse meter opname',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlEnergiemeterDNBMeteropnameFrequentie/YMR')
    }

    @classmethod
    def create_dummy_data(cls):
        return cls.create_dummy_data_keuzelijst(cls.options)




# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.OTLObject import OTLAttribuut
from ...Classes.Abstracten.StaalsoortObject import StaalsoortObject
from ...Classes.Abstracten.TechnischDocument import TechnischDocument
from ...Classes.ImplementatieElement.AIMNaamObject import AIMNaamObject
from ...Datatypes.KlTypeAnkerplaat import KlTypeAnkerplaat
from ...Datatypes.KwantWrdInKiloNewton import KwantWrdInKiloNewton, KwantWrdInKiloNewtonWaarden
from otlmow_model.OtlmowModel.GeometrieTypes.PuntGeometrie import PuntGeometrie


# Generated with OTLClassCreator. To modify: extend, do not edit
class Ankerplaat(StaalsoortObject, TechnischDocument, AIMNaamObject, PuntGeometrie):
    """Een plaat die in de grond is geplaatst of ingebetonneerd en dient om een mechanisch element, zoals een draagstoel, te positioneren en zijn krachten over te dragen aan de omliggende beton- of grondconstructie."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Ankerplaat'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    def __init__(self):
        super().__init__()

        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Draagstoel', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Portiek', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Schommeljuk', direction='u')  # u = unidirectional

        self._kracht = OTLAttribuut(field=KwantWrdInKiloNewton,
                                    naam='kracht',
                                    label='kracht',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Ankerplaat.kracht',
                                    definition='Dit is de voorspankracht in het geval van voorgespannen ankers met tegenplaat en maximale trekkracht in het geval van ingestorte ankers of niet-ingestorte ankers.',
                                    owner=self)

        self._typeAnkerplaat = OTLAttribuut(field=KlTypeAnkerplaat,
                                            naam='typeAnkerplaat',
                                            label='type ankerplaat',
                                            objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Ankerplaat.typeAnkerplaat',
                                            definition='Geeft het type van ankerplaat aan.',
                                            owner=self)

    @property
    def kracht(self) -> KwantWrdInKiloNewtonWaarden:
        """Dit is de voorspankracht in het geval van voorgespannen ankers met tegenplaat en maximale trekkracht in het geval van ingestorte ankers of niet-ingestorte ankers."""
        return self._kracht.get_waarde()

    @kracht.setter
    def kracht(self, value):
        self._kracht.set_waarde(value, owner=self)

    @property
    def typeAnkerplaat(self) -> str:
        """Geeft het type van ankerplaat aan."""
        return self._typeAnkerplaat.get_waarde()

    @typeAnkerplaat.setter
    def typeAnkerplaat(self, value):
        self._typeAnkerplaat.set_waarde(value, owner=self)



# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.OTLObject import OTLAttribuut
from ...Classes.Abstracten.Grondkeringen import Grondkeringen
from ...Classes.Abstracten.WaterremmendeFunctie import WaterremmendeFunctie
from ...Classes.ImplementatieElement.AIMNaamObject import AIMNaamObject
from otlmow_model.OtlmowModel.BaseClasses.BooleanField import BooleanField
from ...Datatypes.DtcDocument import DtcDocument, DtcDocumentWaarden
from ...Datatypes.KwantWrdInCentimeter import KwantWrdInCentimeter, KwantWrdInCentimeterWaarden
from otlmow_model.OtlmowModel.GeometrieTypes.LijnGeometrie import LijnGeometrie
from otlmow_model.OtlmowModel.GeometrieTypes.VlakGeometrie import VlakGeometrie


# Generated with OTLClassCreator. To modify: extend, do not edit
class SecansTangenspalenwand(Grondkeringen, WaterremmendeFunctie, AIMNaamObject, LijnGeometrie, VlakGeometrie):
    """Een secans- of tangenspalenwand bestaat uit betonnen boorpalen. Bij de secanspalenwand zijn dit primaire en secundaire, in elkaar oversneden palen. Bij de tangenspalenwand snijden de boorpalen niet in elkaar in (geen overlap). De wand heeft tot doel een bouwputbeschoeiing te realiseren. De stabiliteit van de grondkering wordt verzekerd door verankeringen en/of schoringen."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/installatie#SecansTangenspalenwand'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    def __init__(self):
        super().__init__()

        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#BalkGK', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Grondanker', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#BetonnenBoorpaal', direction='i')  # i = direction: incoming

        self._hOhAfstandPalen = OTLAttribuut(field=KwantWrdInCentimeter,
                                             naam='hOhAfstandPalen',
                                             label='h. o. h. afstand palen',
                                             objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#SecansTangenspalenwand.hOhAfstandPalen',
                                             definition='Hart op hart afstand tussen palen in de wand.',
                                             owner=self)

        self._heeftInsnijdendePalen = OTLAttribuut(field=BooleanField,
                                                   naam='heeftInsnijdendePalen',
                                                   label='heeft insnijdende palen',
                                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#SecansTangenspalenwand.heeftInsnijdendePalen',
                                                   definition='Bepaling of er insnijdende palen aanwezig zijn.',
                                                   owner=self)

        self._rekennota = OTLAttribuut(field=DtcDocument,
                                       naam='rekennota',
                                       label='rekeningnota',
                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#SecansTangenspalenwand.rekennota',
                                       definition='De bijhorende rekennota met berekeningen.',
                                       owner=self)

    @property
    def hOhAfstandPalen(self) -> KwantWrdInCentimeterWaarden:
        """Hart op hart afstand tussen palen in de wand."""
        return self._hOhAfstandPalen.get_waarde()

    @hOhAfstandPalen.setter
    def hOhAfstandPalen(self, value):
        self._hOhAfstandPalen.set_waarde(value, owner=self)

    @property
    def heeftInsnijdendePalen(self) -> bool:
        """Bepaling of er insnijdende palen aanwezig zijn."""
        return self._heeftInsnijdendePalen.get_waarde()

    @heeftInsnijdendePalen.setter
    def heeftInsnijdendePalen(self, value):
        self._heeftInsnijdendePalen.set_waarde(value, owner=self)

    @property
    def rekennota(self) -> DtcDocumentWaarden:
        """De bijhorende rekennota met berekeningen."""
        return self._rekennota.get_waarde()

    @rekennota.setter
    def rekennota(self, value):
        self._rekennota.set_waarde(value, owner=self)



# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.OTLObject import OTLAttribuut
from ...Classes.ImplementatieElement.NaampadObject import NaampadObject
from otlmow_model.OtlmowModel.BaseClasses.BooleanField import BooleanField
from ...Datatypes.DtcDocument import DtcDocument, DtcDocumentWaarden
from ...Datatypes.KlCADOMerk import KlCADOMerk
from ...Datatypes.KlCADOModelnaam import KlCADOModelnaam
from ...Datatypes.KwantWrdInMeter import KwantWrdInMeter, KwantWrdInMeterWaarden
from otlmow_model.OtlmowModel.GeometrieTypes.LijnGeometrie import LijnGeometrie


# Generated with OTLClassCreator. To modify: extend, do not edit
class Calamiteitendoorsteek(NaampadObject, LijnGeometrie):
    """Een calamiteitendoorsteek,afgekort CADO,is een mechanische constructie voor het opklappen van een deel van de vangrail in de middenberm van een weg. Het primaire doel van de calamiteitendoorsteek is het doorlaten van hulpverleningsvoertuigen."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Calamiteitendoorsteek'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    def __init__(self):
        super().__init__()

        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Fundering', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/implementatieelement#ElectricityCable', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Beschermbuis', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#CalamiteitendoorsteekGroep', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#SluitAanOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#AansluitendeConstructie', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#SluitAanOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#AansluitendeConstructie', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Sturing', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#IOKaart', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#VoedtAangestuurd', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Contactor', direction='i')  # i = direction: incoming

        self._isDubbelArmig = OTLAttribuut(field=BooleanField,
                                           naam='isDubbelArmig',
                                           label='is dubbelarmig',
                                           objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Calamiteitendoorsteek.isDubbelArmig',
                                           definition='Aanduiding of de calamiteitendoorsteek dubbel armig is.',
                                           owner=self)

        self._lengte = OTLAttribuut(field=KwantWrdInMeter,
                                    naam='lengte',
                                    label='lengte',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Calamiteitendoorsteek.lengte',
                                    definition='De totale lengte van de calamiteitendoorsteek constructie.',
                                    owner=self)

        self._merk = OTLAttribuut(field=KlCADOMerk,
                                  naam='merk',
                                  label='merk',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Calamiteitendoorsteek.merk',
                                  definition='Het merk van de calamiteitendoorsteek.',
                                  owner=self)

        self._modelnaam = OTLAttribuut(field=KlCADOModelnaam,
                                       naam='modelnaam',
                                       label='modelnaam',
                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Calamiteitendoorsteek.modelnaam',
                                       definition='De modelnaam van de calamiteitendoorsteek.',
                                       owner=self)

        self._technischeFiche = OTLAttribuut(field=DtcDocument,
                                             naam='technischeFiche',
                                             label='technische fiche',
                                             objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Calamiteitendoorsteek.technischeFiche',
                                             definition='De technische fiche van de calamiteitendoorsteek.',
                                             owner=self)

    @property
    def isDubbelArmig(self) -> bool:
        """Aanduiding of de calamiteitendoorsteek dubbel armig is."""
        return self._isDubbelArmig.get_waarde()

    @isDubbelArmig.setter
    def isDubbelArmig(self, value):
        self._isDubbelArmig.set_waarde(value, owner=self)

    @property
    def lengte(self) -> KwantWrdInMeterWaarden:
        """De totale lengte van de calamiteitendoorsteek constructie."""
        return self._lengte.get_waarde()

    @lengte.setter
    def lengte(self, value):
        self._lengte.set_waarde(value, owner=self)

    @property
    def merk(self) -> str:
        """Het merk van de calamiteitendoorsteek."""
        return self._merk.get_waarde()

    @merk.setter
    def merk(self, value):
        self._merk.set_waarde(value, owner=self)

    @property
    def modelnaam(self) -> str:
        """De modelnaam van de calamiteitendoorsteek."""
        return self._modelnaam.get_waarde()

    @modelnaam.setter
    def modelnaam(self, value):
        self._modelnaam.set_waarde(value, owner=self)

    @property
    def technischeFiche(self) -> DtcDocumentWaarden:
        """De technische fiche van de calamiteitendoorsteek."""
        return self._technischeFiche.get_waarde()

    @technischeFiche.setter
    def technischeFiche(self, value):
        self._technischeFiche.set_waarde(value, owner=self)



# coding=utf-8
from typing import List
from otlmow_model.OtlmowModel.BaseClasses.OTLObject import OTLAttribuut
from ...Classes.Abstracten.AanhorigheidSluisStuw import AanhorigheidSluisStuw
from ...Classes.Abstracten.Toegangselement import Toegangselement
from ...Classes.ImplementatieElement.NaampadObject import NaampadObject
from otlmow_model.OtlmowModel.BaseClasses.BooleanField import BooleanField
from ...Datatypes.DtcAfmetingBxhInM import DtcAfmetingBxhInM, DtcAfmetingBxhInMWaarden
from ...Datatypes.DtcDocument import DtcDocument, DtcDocumentWaarden
from ...Datatypes.KlDeurFabrikant import KlDeurFabrikant
from ...Datatypes.KlDeurHandgreeptype import KlDeurHandgreeptype
from ...Datatypes.KlDeurType import KlDeurType
from ...Datatypes.KlToegangsdeurTypeOpening import KlToegangsdeurTypeOpening
from ...Datatypes.KwantWrdInMillimeter import KwantWrdInMillimeter, KwantWrdInMillimeterWaarden
from ...Datatypes.KwantWrdInSeconde import KwantWrdInSeconde, KwantWrdInSecondeWaarden
from ...Datatypes.KwantWrdInUur import KwantWrdInUur, KwantWrdInUurWaarden
from otlmow_model.OtlmowModel.GeometrieTypes.PuntGeometrie import PuntGeometrie


# Generated with OTLClassCreator. To modify: extend, do not edit
class Deur(AanhorigheidSluisStuw, Toegangselement, NaampadObject, PuntGeometrie):
    """Een beweegbaar element ter afsluiting van een ruimte. In een gebouw is een deur meestal bevestigd in een kozijn,dat weer in een muur of wand is aangebracht."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Deur'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    def __init__(self):
        super().__init__()

        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Wand', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Aanstraalverlichting', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Contourverlichting', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Pictogram', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#GeluidwerendeConstructie', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Hulppost', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Vluchtganginrichting', direction='o')  # o = direction: outgoing

        self._afmetingDeuropening = OTLAttribuut(field=DtcAfmetingBxhInM,
                                                 naam='afmetingDeuropening',
                                                 label='afmeting deuropening',
                                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Deur.afmetingDeuropening',
                                                 definition='Afmeting van de vrije ruimte die ontstaat wanneer de deur volledig geopend is.',
                                                 owner=self)

        self._brandweerstand = OTLAttribuut(field=KwantWrdInUur,
                                            naam='brandweerstand',
                                            label='brandweerstand',
                                            objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Deur.brandweerstand',
                                            definition='Brandwerendheid is een maat voor de tijd die een constructie heeft voor dat deze bezwijkt onder invloed van een brand.',
                                            owner=self)

        self._breedte = OTLAttribuut(field=KwantWrdInMillimeter,
                                     naam='breedte',
                                     label='breedte',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Deur.breedte',
                                     definition='De afmeting van de rechtopstaande deur gemeten van de ene zijkant naar de andere.',
                                     owner=self)

        self._dikte = OTLAttribuut(field=KwantWrdInMillimeter,
                                   naam='dikte',
                                   label='dikte',
                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Deur.dikte',
                                   definition='De dikte van de deur gemeten van de ene buitenzijde van de deur tot de andere.',
                                   owner=self)

        self._fabrikant = OTLAttribuut(field=KlDeurFabrikant,
                                       naam='fabrikant',
                                       label='fabrikant',
                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Deur.fabrikant',
                                       definition='Naam van de producent van de deur.',
                                       owner=self)

        self._handgreeptype = OTLAttribuut(field=KlDeurHandgreeptype,
                                           naam='handgreeptype',
                                           label='handgreeptype',
                                           objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Deur.handgreeptype',
                                           definition='Soort greep aan waarmee de deur geopend wordt.',
                                           owner=self)

        self._hoogte = OTLAttribuut(field=KwantWrdInMillimeter,
                                    naam='hoogte',
                                    label='hoogte',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Deur.hoogte',
                                    definition='De afmeting van de rechtopstaande deur gemeten van de onderkant tot de bovenkant.',
                                    owner=self)

        self._isWaterdicht = OTLAttribuut(field=BooleanField,
                                          naam='isWaterdicht',
                                          label='is waterdicht',
                                          objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Deur.isWaterdicht',
                                          definition='Geeft aan of de deur al dan niet waterdicht is.',
                                          owner=self)

        self._ophangconstructie = OTLAttribuut(field=DtcDocument,
                                               naam='ophangconstructie',
                                               label='ophangconstructie',
                                               objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Deur.ophangconstructie',
                                               definition='Documentatie met betrekking tot de manier waarop de deur met het kozijn bevestigd is aan de ruimte waartoe ze toegang biedt.',
                                               owner=self)

        self._sluitingstijd = OTLAttribuut(field=KwantWrdInSeconde,
                                           naam='sluitingstijd',
                                           label='sluitingstijd',
                                           objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Deur.sluitingstijd',
                                           definition='Duurtijd voor het automatische sluiten van een zelfsluitende deur die volledig open staat.',
                                           owner=self)

        self._typeDeur = OTLAttribuut(field=KlDeurType,
                                      naam='typeDeur',
                                      label='type deur',
                                      objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Deur.typeDeur',
                                      kardinaliteit_max='*',
                                      definition='Aanduiding tot welk type de deur behoort.',
                                      owner=self)

        self._typeOpening = OTLAttribuut(field=KlToegangsdeurTypeOpening,
                                         naam='typeOpening',
                                         label='type opening',
                                         objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Deur.typeOpening',
                                         definition='Geeft aan hoe de deur in de af te sluiten ruimte draait of schuift.',
                                         owner=self)

    @property
    def afmetingDeuropening(self) -> DtcAfmetingBxhInMWaarden:
        """Afmeting van de vrije ruimte die ontstaat wanneer de deur volledig geopend is."""
        return self._afmetingDeuropening.get_waarde()

    @afmetingDeuropening.setter
    def afmetingDeuropening(self, value):
        self._afmetingDeuropening.set_waarde(value, owner=self)

    @property
    def brandweerstand(self) -> KwantWrdInUurWaarden:
        """Brandwerendheid is een maat voor de tijd die een constructie heeft voor dat deze bezwijkt onder invloed van een brand."""
        return self._brandweerstand.get_waarde()

    @brandweerstand.setter
    def brandweerstand(self, value):
        self._brandweerstand.set_waarde(value, owner=self)

    @property
    def breedte(self) -> KwantWrdInMillimeterWaarden:
        """De afmeting van de rechtopstaande deur gemeten van de ene zijkant naar de andere."""
        return self._breedte.get_waarde()

    @breedte.setter
    def breedte(self, value):
        self._breedte.set_waarde(value, owner=self)

    @property
    def dikte(self) -> KwantWrdInMillimeterWaarden:
        """De dikte van de deur gemeten van de ene buitenzijde van de deur tot de andere."""
        return self._dikte.get_waarde()

    @dikte.setter
    def dikte(self, value):
        self._dikte.set_waarde(value, owner=self)

    @property
    def fabrikant(self) -> str:
        """Naam van de producent van de deur."""
        return self._fabrikant.get_waarde()

    @fabrikant.setter
    def fabrikant(self, value):
        self._fabrikant.set_waarde(value, owner=self)

    @property
    def handgreeptype(self) -> str:
        """Soort greep aan waarmee de deur geopend wordt."""
        return self._handgreeptype.get_waarde()

    @handgreeptype.setter
    def handgreeptype(self, value):
        self._handgreeptype.set_waarde(value, owner=self)

    @property
    def hoogte(self) -> KwantWrdInMillimeterWaarden:
        """De afmeting van de rechtopstaande deur gemeten van de onderkant tot de bovenkant."""
        return self._hoogte.get_waarde()

    @hoogte.setter
    def hoogte(self, value):
        self._hoogte.set_waarde(value, owner=self)

    @property
    def isWaterdicht(self) -> bool:
        """Geeft aan of de deur al dan niet waterdicht is."""
        return self._isWaterdicht.get_waarde()

    @isWaterdicht.setter
    def isWaterdicht(self, value):
        self._isWaterdicht.set_waarde(value, owner=self)

    @property
    def ophangconstructie(self) -> DtcDocumentWaarden:
        """Documentatie met betrekking tot de manier waarop de deur met het kozijn bevestigd is aan de ruimte waartoe ze toegang biedt."""
        return self._ophangconstructie.get_waarde()

    @ophangconstructie.setter
    def ophangconstructie(self, value):
        self._ophangconstructie.set_waarde(value, owner=self)

    @property
    def sluitingstijd(self) -> KwantWrdInSecondeWaarden:
        """Duurtijd voor het automatische sluiten van een zelfsluitende deur die volledig open staat."""
        return self._sluitingstijd.get_waarde()

    @sluitingstijd.setter
    def sluitingstijd(self, value):
        self._sluitingstijd.set_waarde(value, owner=self)

    @property
    def typeDeur(self) -> List[str]:
        """Aanduiding tot welk type de deur behoort."""
        return self._typeDeur.get_waarde()

    @typeDeur.setter
    def typeDeur(self, value):
        self._typeDeur.set_waarde(value, owner=self)

    @property
    def typeOpening(self) -> str:
        """Geeft aan hoe de deur in de af te sluiten ruimte draait of schuift."""
        return self._typeOpening.get_waarde()

    @typeOpening.setter
    def typeOpening(self, value):
        self._typeOpening.set_waarde(value, owner=self)



# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.OTLObject import OTLAttribuut
from ...Classes.Abstracten.AanhorigheidSluisStuw import AanhorigheidSluisStuw
from ...Classes.Abstracten.DetaiplanObject import DetaiplanObject
from ...Classes.ImplementatieElement.AIMNaamObject import AIMNaamObject
from ...Datatypes.KwantWrdInKiloNewton import KwantWrdInKiloNewton, KwantWrdInKiloNewtonWaarden
from otlmow_model.OtlmowModel.BaseClasses.StringField import StringField
from otlmow_model.OtlmowModel.GeometrieTypes.PuntGeometrie import PuntGeometrie


# Generated with OTLClassCreator. To modify: extend, do not edit
class Haalkom(AanhorigheidSluisStuw, DetaiplanObject, AIMNaamObject, PuntGeometrie):
    """Een haalkom is een voorziening in een sluis- of kademuur waaraan men een schip kan vastmaken."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Haalkom'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    def __init__(self):
        super().__init__()

        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Kesp', direction='u')  # u = unidirectional

        self._materiaalKom = OTLAttribuut(field=StringField,
                                          naam='materiaalKom',
                                          label='materiaal kom',
                                          objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Haalkom.materiaalKom',
                                          definition='Het gebruikte materiaal voor de kom (Bijv: GE300, GS24Mn6,..).',
                                          owner=self)

        self._materiaalPen = OTLAttribuut(field=StringField,
                                          naam='materiaalPen',
                                          label='materiaal pen',
                                          objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Haalkom.materiaalPen',
                                          definition='Het gebruikte materiaal voor de pen (Bijv: 42CrMo4,..).',
                                          owner=self)

        self._maximaleTroskracht = OTLAttribuut(field=KwantWrdInKiloNewton,
                                                naam='maximaleTroskracht',
                                                label='maximale troskracht',
                                                objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Haalkom.maximaleTroskracht',
                                                definition='De maximale troskracht, uitgedrukt in kN (Karakteristieke waarde).',
                                                owner=self)

    @property
    def materiaalKom(self) -> str:
        """Het gebruikte materiaal voor de kom (Bijv: GE300, GS24Mn6,..)."""
        return self._materiaalKom.get_waarde()

    @materiaalKom.setter
    def materiaalKom(self, value):
        self._materiaalKom.set_waarde(value, owner=self)

    @property
    def materiaalPen(self) -> str:
        """Het gebruikte materiaal voor de pen (Bijv: 42CrMo4,..)."""
        return self._materiaalPen.get_waarde()

    @materiaalPen.setter
    def materiaalPen(self, value):
        self._materiaalPen.set_waarde(value, owner=self)

    @property
    def maximaleTroskracht(self) -> KwantWrdInKiloNewtonWaarden:
        """De maximale troskracht, uitgedrukt in kN (Karakteristieke waarde)."""
        return self._maximaleTroskracht.get_waarde()

    @maximaleTroskracht.setter
    def maximaleTroskracht(self, value):
        self._maximaleTroskracht.set_waarde(value, owner=self)



# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.OTLObject import OTLAttribuut
from ...Classes.Abstracten.PU import PU
from ...Classes.ImplementatieElement.NaampadObject import NaampadObject
from otlmow_model.OtlmowModel.BaseClasses.BooleanField import BooleanField
from ...Datatypes.DtcDocument import DtcDocument, DtcDocumentWaarden
from ...Datatypes.KlDynBordExternePUMerk import KlDynBordExternePUMerk
from ...Datatypes.KlDynBordExternePUModelnaam import KlDynBordExternePUModelnaam


# Generated with OTLClassCreator. To modify: extend, do not edit
class DynBordExternePU(PU, NaampadObject):
    """Externe stuureenheid die buiten het dynamisch bord bevestigd is,in de buurt van de openbare weg. Het betreft dus geen stuureenheid in een serverroom,noch een stuureenheid op het bord zelf."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#DynBordExternePU'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    def __init__(self):
        super().__init__()

        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Kast', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Z30Groep', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Sturing', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#LEDBord', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Sturing', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#SoftwareToegang', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Sturing', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#BiFlash', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Sturing', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Knipperlantaarn', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Sturing', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#NetwerkModem', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Sturing', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Netwerkpoort', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Voedt', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Laagspanningsbord', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Voedt', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Stroomkring', direction='i')  # i = direction: incoming

        self._heeftGeintegreerdeModem = OTLAttribuut(field=BooleanField,
                                                     naam='heeftGeintegreerdeModem',
                                                     label='heeft geintegreerde modem',
                                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#DynBordExternePU.heeftGeintegreerdeModem',
                                                     definition='De PU heeft een geïntegreerde modem.',
                                                     owner=self)

        self._merk = OTLAttribuut(field=KlDynBordExternePUMerk,
                                  naam='merk',
                                  label='merk',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#DynBordExternePU.merk',
                                  definition='Het merk van de externe PU volgens een keuzelijst.',
                                  owner=self)

        self._modelnaam = OTLAttribuut(field=KlDynBordExternePUModelnaam,
                                       naam='modelnaam',
                                       label='modelnaam',
                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#DynBordExternePU.modelnaam',
                                       definition='De modelnaam van de externe PU volgens een keuzelijst.',
                                       owner=self)

        self._technischeFiche = OTLAttribuut(field=DtcDocument,
                                             naam='technischeFiche',
                                             label='technische fiche',
                                             objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#DynBordExternePU.technischeFiche',
                                             definition='Document met technische informatie over de PU.',
                                             owner=self)

    @property
    def heeftGeintegreerdeModem(self) -> bool:
        """De PU heeft een geïntegreerde modem."""
        return self._heeftGeintegreerdeModem.get_waarde()

    @heeftGeintegreerdeModem.setter
    def heeftGeintegreerdeModem(self, value):
        self._heeftGeintegreerdeModem.set_waarde(value, owner=self)

    @property
    def merk(self) -> str:
        """Het merk van de externe PU volgens een keuzelijst."""
        return self._merk.get_waarde()

    @merk.setter
    def merk(self, value):
        self._merk.set_waarde(value, owner=self)

    @property
    def modelnaam(self) -> str:
        """De modelnaam van de externe PU volgens een keuzelijst."""
        return self._modelnaam.get_waarde()

    @modelnaam.setter
    def modelnaam(self, value):
        self._modelnaam.set_waarde(value, owner=self)

    @property
    def technischeFiche(self) -> DtcDocumentWaarden:
        """Document met technische informatie over de PU."""
        return self._technischeFiche.get_waarde()

    @technischeFiche.setter
    def technischeFiche(self, value):
        self._technischeFiche.set_waarde(value, owner=self)



# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.OTLObject import OTLAttribuut
from ...Classes.ImplementatieElement.AIMObject import AIMObject
from ...Datatypes.KlMateriaalVentilatiekanaal import KlMateriaalVentilatiekanaal
from ...Datatypes.KwantWrdInVierkanteMeter import KwantWrdInVierkanteMeter, KwantWrdInVierkanteMeterWaarden
from otlmow_model.OtlmowModel.GeometrieTypes.LijnGeometrie import LijnGeometrie


# Generated with OTLClassCreator. To modify: extend, do not edit
class Ventilatiekanaal(AIMObject, LijnGeometrie):
    """Een buis die paarsgewijs zorgt voor passieve verluchting van een afgesloten ruimte door langs de ene buis lucht naar binnen en door de andere naar buiten te laten stromen op basis van de hoogte ten opzichte van elkaar."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Ventilatiekanaal'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    def __init__(self):
        super().__init__()

        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Verluchtingskap', direction='u')  # u = unidirectional

        self._materiaal = OTLAttribuut(field=KlMateriaalVentilatiekanaal,
                                       naam='materiaal',
                                       label='materiaal ventilatiekanaal',
                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Ventilatiekanaal.materiaal',
                                       definition='Het materiaal van een ventilatiekanaal verwijst naar de substantie waaruit het kanaal is vervaardigd.',
                                       owner=self)

        self._oppervlakte = OTLAttribuut(field=KwantWrdInVierkanteMeter,
                                         naam='oppervlakte',
                                         label='oppervlakte ventilatiekanaal',
                                         objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Ventilatiekanaal.oppervlakte',
                                         definition='De oppervlakte van het ventilatiekanaal is de totale doorsnede van het kanaal en vertegenwoordigt het gebied dat beschikbaar is voor de luchtstroom binnenin.',
                                         owner=self)

    @property
    def materiaal(self) -> str:
        """Het materiaal van een ventilatiekanaal verwijst naar de substantie waaruit het kanaal is vervaardigd."""
        return self._materiaal.get_waarde()

    @materiaal.setter
    def materiaal(self, value):
        self._materiaal.set_waarde(value, owner=self)

    @property
    def oppervlakte(self) -> KwantWrdInVierkanteMeterWaarden:
        """De oppervlakte van het ventilatiekanaal is de totale doorsnede van het kanaal en vertegenwoordigt het gebied dat beschikbaar is voor de luchtstroom binnenin."""
        return self._oppervlakte.get_waarde()

    @oppervlakte.setter
    def oppervlakte(self, value):
        self._oppervlakte.set_waarde(value, owner=self)



# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.KeuzelijstField import KeuzelijstField
from otlmow_model.OtlmowModel.BaseClasses.KeuzelijstWaarde import KeuzelijstWaarde


# Generated with OTLEnumerationCreator. To modify: extend, do not edit
class KlTypeWand(KeuzelijstField):
    """De functie die de wand uitoefent."""
    naam = 'KlTypeWand'
    label = 'Type wand'
    objectUri = 'https://wegenenverkeer.data.vlaanderen.be/ns/installatie#KlTypeWand'
    definition = 'De functie die de wand uitoefent.'
    status = 'ingebruik'
    codelist = 'https://wegenenverkeer.data.vlaanderen.be/id/conceptscheme/KlTypeWand'
    options = {
        'binnenwand': KeuzelijstWaarde(invulwaarde='binnenwand',
                                       label='binnenwand',
                                       status='ingebruik',
                                       definitie='Wand zonder dragende functie, meestal gebruikt om ruimtes van elkaar te scheiden.',
                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlTypeWand/binnenwand'),
        'brilwand': KeuzelijstWaarde(invulwaarde='brilwand',
                                     label='brilwand',
                                     status='ingebruik',
                                     definitie='Wand met een uitsparing/opening voor het doorlaten van een tunnelboormachine.',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlTypeWand/brilwand'),
        'frontmuur': KeuzelijstWaarde(invulwaarde='frontmuur',
                                      label='frontmuur',
                                      status='ingebruik',
                                      definitie=' Muur van een landhoofd die de belastingen van de bovenbouw van de brug afdraagt.',
                                      objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlTypeWand/frontmuur'),
        'retourmuur': KeuzelijstWaarde(invulwaarde='retourmuur',
                                       label='retourmuur',
                                       status='ingebruik',
                                       definitie='Zijdelingse muur van een landhoofd die ongeveer evenwijdig is met de brugas.',
                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlTypeWand/retourmuur'),
        'scheenmuur': KeuzelijstWaarde(invulwaarde='scheenmuur',
                                       label='scheenmuur',
                                       status='ingebruik',
                                       definitie='Grondkerende muur op de zool of frontmuur van een landhoofd die de voeg ondersteund en de vlotplaat draagt. De scheenmuur draagt geen belastingen van de bovenbouw van de brug af.',
                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlTypeWand/scheenmuur'),
        'steunwand': KeuzelijstWaarde(invulwaarde='steunwand',
                                      label='steunwand',
                                      status='ingebruik',
                                      definitie='Wand die ontworpen is om belastingen te dragen.',
                                      objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlTypeWand/steunwand'),
        'tunnelfronton': KeuzelijstWaarde(invulwaarde='tunnelfronton',
                                          label='tunnelfronton',
                                          status='ingebruik',
                                          definitie='Het voorste deel van een tunnel, dat de overgang vormt tussen de tunnelopening en het omliggende landschap. Het biedt structurele ondersteuning en bescherming tegen instorting en erosie rond de tunnelopening.',
                                          objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlTypeWand/tunnelfronton'),
        'vleugelmuur': KeuzelijstWaarde(invulwaarde='vleugelmuur',
                                        label='vleugelmuur',
                                        status='ingebruik',
                                        definitie=' Zijdelingse muur van een landhoofd die in het verlengde ligt van de frontmuur.',
                                        objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlTypeWand/vleugelmuur')
    }

    @classmethod
    def create_dummy_data(cls):
        return cls.create_dummy_data_keuzelijst(cls.options)




# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.OTLObject import OTLAttribuut
from ...Classes.Abstracten.TechnischDocument import TechnischDocument
from ...Classes.ImplementatieElement.AIMNaamObject import AIMNaamObject
from ...Datatypes.KwantWrdInBar import KwantWrdInBar, KwantWrdInBarWaarden
from otlmow_model.OtlmowModel.GeometrieTypes.PuntGeometrie import PuntGeometrie


# Generated with OTLClassCreator. To modify: extend, do not edit
class Drukvat(TechnischDocument, AIMNaamObject, PuntGeometrie):
    """Een afgesloten vat waarin een gas of vloeistof onder een andere druk dan de omgevingsdruk wordt opgeslagen. Het dient om de impact van een bewegend lichaam op te vangen en kan verbonden zijn met een buffercilinder. Dit wordt ook wel een buffervat genoemd."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Drukvat'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    def __init__(self):
        super().__init__()

        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Bufferinstallatie', direction='o')  # o = direction: outgoing

        self._maximaleDruk = OTLAttribuut(field=KwantWrdInBar,
                                          naam='maximaleDruk',
                                          label='maximale druk',
                                          objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Drukvat.maximaleDruk',
                                          definition='De hoogste druk die het drukvat kan weerstaan zonder te falen of beschadigd te raken. Dit wordt bepaald door het materiaal, de constructie en de toepassing van het drukvat. Het wordt vaak vastgesteld door middel van testen onder gecontroleerde omstandigheden, waarbij het drukvat geleidelijk aan toenemende druk wordt blootgesteld totdat deze faalt. De druk net voordat het drukvat faalt, wordt beschouwd als de maximale druk. In de praktijk wordt vaak een veiligheidsmarge toegepast.',
                                          owner=self)

    @property
    def maximaleDruk(self) -> KwantWrdInBarWaarden:
        """De hoogste druk die het drukvat kan weerstaan zonder te falen of beschadigd te raken. Dit wordt bepaald door het materiaal, de constructie en de toepassing van het drukvat. Het wordt vaak vastgesteld door middel van testen onder gecontroleerde omstandigheden, waarbij het drukvat geleidelijk aan toenemende druk wordt blootgesteld totdat deze faalt. De druk net voordat het drukvat faalt, wordt beschouwd als de maximale druk. In de praktijk wordt vaak een veiligheidsmarge toegepast."""
        return self._maximaleDruk.get_waarde()

    @maximaleDruk.setter
    def maximaleDruk(self, value):
        self._maximaleDruk.set_waarde(value, owner=self)



# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.KeuzelijstField import KeuzelijstField
from otlmow_model.OtlmowModel.BaseClasses.KeuzelijstWaarde import KeuzelijstWaarde


# Generated with OTLEnumerationCreator. To modify: extend, do not edit
class KlTelecommunicationsSubthema(KeuzelijstField):
    """Lijst voor classificatie van een kabels en appurtenance voor telecommunicatie."""
    naam = 'KlTelecommunicationsSubthema'
    label = 'Telecommunications subthema'
    objectUri = 'https://wegenenverkeer.data.vlaanderen.be/ns/implementatieelement#KlTelecommunicationsSubthema'
    definition = 'Lijst voor classificatie van een kabels en appurtenance voor telecommunicatie.'
    status = 'ingebruik'
    codelist = 'https://wegenenverkeer.data.vlaanderen.be/id/conceptscheme/KlTelecommunicationsSubthema'
    options = {
        'elektronischecommunicatie': KeuzelijstWaarde(invulwaarde='elektronischecommunicatie',
                                                      label='elektronischeCommunicatie',
                                                      status='ingebruik',
                                                      definitie='elektronischeCommunicatie',
                                                      objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlTelecommunicationsSubthema/elektronischecommunicatie')
    }

    @classmethod
    def create_dummy_data(cls):
        return cls.create_dummy_data_keuzelijst(cls.options)

